@@ -4,7 +4,7 @@ use Carp;
 use strict;
 use vars qw($VERSION $PACKAGE @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 $PACKAGE = 'ShiftJIS::Collate'; # __PACKAGE__
 
@@ -994,7 +994,7 @@ ShiftJIS::Collate - collation of Shift_JIS strings
 
   use ShiftJIS::Collate;
 
-  @sorted = ShiftJIS::Collate->new(%tailoring)->sort(@not_sorted);
+  @sorted = ShiftJIS::Collate->new(%tailoring)->sort(@source);
 
 =head1 ABOUT THIS POD
 
@@ -1012,7 +1012,7 @@ in Shift_JIS based on the collation of Japanese character strings.
 
 This module is an implementation of B<JIS X 4061:1996> and
 the collation rules are based on that standard.
-See L<Conformance on the Standard>.
+See L<Conformance to the Standard>.
 
 =head2 Constructor and Tailoring
 
@@ -1038,7 +1038,7 @@ The C<new> method returns a collator object.
 If specified as a regular expression,
 any characters that match it are ignored on collation.
 
-e.g. If you want to ignore KATAKANA PROLONGED SOUND MARK
+e.g. If you want to ignore C<KATAKANA-HIRAGANA PROLONGED SOUND MARK>
 and its halfwidth form, say
 
    ignoreChar => '^(?:\x81\x5B|\xB0)',
@@ -1141,21 +1141,6 @@ They works like the same name operators as theirs.
 
 =over 4
 
-=item C<@sorted = $Collator-E<gt>sort(@not_sorted)>
-
-Sorts a list of strings by B<tanjun shogo>: 'the simple collation'.
-
-=item C<@sorted = $Collator-E<gt>sortYomi(@not_sorted)>
-
-Sorts a list of references to arrays of (spell, reading)
-by B<yomi-hyoki shogo>: 'the collation using readings and spells'.
-
-=item C<@sorted = $Collator-E<gt>sortDaihyo(@not_sorted)>
-
-Sorts a list of references to arrays of (spell, reading)
-by B<kan'i-daihyo-yomi shogo>:
-'the simplified representative reading collation'.
-
 =item C<$sortKey = $Collator-E<gt>getSortKey($string)>
 
 Returns a sort key.
@@ -1169,6 +1154,98 @@ and get the result of the comparison of the strings.
 
    $Collator->cmp($a, $b)
 
+=item C<@sorted = $Collator-E<gt>sort(@source)>
+
+Sorts a list of strings by B<tanjun shogo>: 'the simple collation'.
+
+=item C<@sorted = $Collator-E<gt>sortYomi(@source)>
+
+Sorts a list of references to arrays of (spell, reading)
+by B<yomi-hyoki shogo>: 'the collation using readings and spells'.
+
+E.g., an element of @source is probably C<['{', 'ɂق']>;
+Its opposite, C<['ɂق', '{']>, is also allowed, though.
+
+B<Yomi-hyoki shogo> is carried out through two comparison stages.
+
+E.g., sort these strings by 'Yomi-hyoki shogo'.
+
+C<['ic', 'Ȃ']>, C<['R', '']>, C<['c', '']>, C<['c', 'Ȃ']>, C<['R', '']>.
+
+First, order by reading
+(C<''> E<lt> C<''> E<lt> '' E<lt> 'Ȃ');
+next, order by spelling among strings having the same reading (C<'ic'> E<lt> C<'c'> where both are read as C<'Ȃ'>).
+
+The result should be C<['c', '']> E<lt> C<['R', '']> E<lt> C<['R', '']> E<lt> C<['ic', 'Ȃ']> E<lt> C<['c', 'Ȃ']>.
+
+See also F<sample/yomi.txt>.
+
+=item C<@sorted = $Collator-E<gt>sortDaihyo(@source)>
+
+Sorts a list of references to arrays of (spell, reading)
+by B<kan'i-daihyo-yomi shogo>:
+'the simplified representative reading collation'.
+
+B<kan'i-daihyo-yomi shogo> is carried out through B<five> comparison stages.
+This ordered list is an example of the result of C<"kan'i-daihyo-yomi shogo">.
+
+  ['Sʑ', '߂񂽂'],
+  ['QF', 'ɂ傭'],
+  ['S', '悶'],
+  ['Uʑ', '낭߂񂽂'],
+  ['', 'At@ق'],
+  ['֐', 'K}񂷂'],
+  ['',   'x[^'],
+  ['pl',   'L['],
+  ['ihr', ''],
+  ['Perl',   'p['],
+  ['͐',   ''],
+  ['͍',   '킢'],
+  ['͓c',   '킾'],
+  ['͓',   '킿'],
+  ['͕',   ''],
+  ['pc',   ''],
+  ['pc',   'ǂ'],
+  ['֓',   'Ƃ'],
+  ['͓',   ''],
+  ['',   '킵'],
+  ['',   '킵'],
+  ['c',   '킾'],
+  ['V',   '킵'],
+  ['V',   '킵'],
+  ['Vc',   '킾'],
+  ['pc',   '̂'],
+  ['y',   ''],
+  ['y',   ''],
+  ['y',   'ǂ'],
+  ['y',   'ǂ'],
+
+(1) Compare the character class of the first character of the spell.
+
+  Digit class ('Sʑ') < Greek class ('') < Latin class ('ihr') < Kanji class ('֓').
+
+(2) Compare the first character of the reading.
+
+  e.g. '߂񂽂' < 'ɂ傭' < '悶' < '낭߂񂽂'.
+
+(3) Compare the first character of the spell.
+
+  e.g. ('͐','͓c',etc.) < ('pc','pc') < ('֓');
+
+       ('','','c') < ('V','V','Vc').
+
+(4) Compare the whole string of the reading.
+
+  e.g. ['͐', ''] < ['͍', '킢'] < ['͓c', '킾'];
+
+       ['pc', ''] < ['pc', 'ǂ'].
+
+(5) Compare the whole string of the spell.
+
+  e.g. ['', '킵'] < ['', '킵'] < ['c', '킾'].
+
+See also F<sample/daihyo.txt>.
+
 =back
 
 =head2 Searching
@@ -1220,7 +1297,7 @@ specify true as C<position_in_bytes>. See L<Constructor and Tailoring>.
 The following criteria are considered in order
 until the collation order is determined.
 By default, Levels 1 to 4 are applied and Level 5 is ignored
-(as JIS does).
+(as JIS does NOT specify level 5).
 
 =over 4
 
@@ -1233,18 +1310,25 @@ The character class early appeared in the following list is smaller.
     and Geta mark.
 
 In the class, alphabets are collated alphabetically;
-kana letters are AIUEO-betically (in the Gozyuon order);
+kana letters are AIUEO-betically (in the Gozyuon order, '܏\');
 kanji are in the JIS X 0208 order.
 
 Characters that do not belong to any character class are
 ignored and skipped for collation.
 
+Geta mark ('', 0x81AC, U+3013) is the greatest character
+ (ordered at the last).
+
+Any character for which the order is no defined,
+like control characters, box drawings, unassigned characters, etc.
+is regarded as a completely ignorable character.
+
 =item Level 2: diacritic ordering.
 
 In kana, the order is as shown the following list.
 
     A voiceless kana, the voiced, then the semi-voiced (if exists).
-     (eg. Ka < Ga; Ha < Ba < Pa)
+     (eg. '' < ''; '' < '' < '')
 
 =item Level 3: case ordering.
 
@@ -1253,22 +1337,27 @@ A small Latin is lesser than the corresponding Capital.
 In kana, the order is as shown the following list.
 see L<Replacement of PROLONGED SOUND MARK and ITERATION MARKs>.
 
-    Replaced PROLONGED SOUND MARK (U+30FC);
+    Replaced PROLONGED SOUND MARKs (U+30FC and U+FF70);
     Small Kana;
-    Replaced ITERATION MARK (U+309D, U+309E, U+30FD or U+30FE);
+    Replaced ITERATION MARKs (U+309D, U+309E, U+30FD, and U+30FE);
     then, Normal Kana.
 
+    Then, e.g., '[' < '' < 'T' < ''.
+
 =item Level 4: script ordering.
 
 Any hiragana is lesser than the corresponding katakana.
 
+    Then, e.g., '' < 'A'.
+
 =item Level 5: width ordering.
 
 A character that belongs to the block
 C<Halfwidth and Fullwidth Forms>
 is greater than the corresponding normal character.
 
-B<BN:> JIS does not mention this level. Extenstion by this module.
+B<BN: JIS does not mention this level.
+Level 5 is an extention by this module.>
 
 =back
 
@@ -1281,8 +1370,11 @@ There are three kanji classes. This modules provides the Classes 1 and 2.
 =item Class 1: the 'saisho' (minimal) kanji class
 
 It comprises five kanji-like characters,
-i.e. U+3003, U+3005, U+4EDD, U+3006, U+3007.
-Any kanji except U+4EDD are ignored on collation.
+i.e. 'V' (0x8156, U+3003), 'X' (0x8158, U+3005),
+'W' (0x8157, U+4EDD), 'Y' (0x8159, U+3006),
+and 'Z' (0x815A, U+3007).
+
+Any kanji except 'W' are ignored on collation.
 
 =item Class 2: the 'kihon' (basic) kanji class
 
@@ -1297,55 +1389,65 @@ the minimal kanji class. Sorted in the Unicode codepoint order.
 
 =back
 
-=head2 Replacement of PROLONGED SOUND MARK and ITERATION MARKs
+=head2 Replacement of PROLONGED SOUND MARKs and ITERATION MARKs
 
-        Character    UCS
-	  'T'    U+309D  HIRAGANA ITERATION MARK
-	  'U'    U+309E  HIRAGANA VOICED ITERATION MARK
-	  '['    U+30FC  KATAKANA-HIRAGANA PROLONGED SOUND MARK
-	  'R'    U+30FD  KATAKANA ITERATION MARK
-	  'S'    U+30FE  KATAKANA VOICED ITERATION MARK
+   Character  SJIS    UCS     Name
+
+     '['    0x815B  U+30FC  KATAKANA-HIRAGANA PROLONGED SOUND MARK
+     ''     0xB0    U+FF70  HALFWIDTH KATAKANA-HIRAGANA PROLONGED SOUND MARK
+     'T'    0x8154  U+309D  HIRAGANA ITERATION MARK
+     'U'    0x8155  U+309E  HIRAGANA VOICED ITERATION MARK
+     'R'    0x8152  U+30FD  KATAKANA ITERATION MARK
+     'S'    0x8153  U+30FE  KATAKANA VOICED ITERATION MARK
 
 These characters, if replaced, are secondary equal to
 the replacing kana, while ternary not equal to.
 
 =over 4
 
-=item KATAKANA-HIRAGANA PROLONGED SOUND MARK
+=item KATAKANA-HIRAGANA PROLONGED SOUND MARKs
 
-The PROLONGED MARK is repleced to a normal vowel or nasal
+The PROLONGED MARKs (including the halfwidth equivalent)
+are repleced to a normal vowel or nasal
 katakana corresponding to the preceding kana if exists.
 
-  eg.	'J['   to 'JA'
-	'с['   to 'уC'
-	'[' to 'A'
-	's[' to 'sE'
-	'['   to ''
+  e.g.,
+
+  'J['   to 'JA'
+  'с['   to 'уC'
+  '[' to 'A'
+  's[' to 'sE'
+  '['   to ''
+  '[[' to '񃓃'
 
 =item HIRAGANA- and KATAKANA ITERATION MARKs
 
 The ITERATION MARKs (VOICELESS) are repleced
 to a normal kana corresponding to the preceding kana if exists.
 
-  eg.	'T'   to ''
-	'hT'   to 'h'
-	'T'   to ''
-	'JR'   to 'JJ'
-	'΁R'   to '΃n'
-	'vR'   to 'vt'
-	'BR' to 'BC'
-	'sT' to 's'
+  e.g.,
+
+  'T'   to ''
+  'hT'   to 'h'
+  'T'   to ''
+  'JR'   to 'JJ'
+  '΁R'   to '΃n'
+  'vR'   to 'vt'
+  'BR' to 'BC'
+  'sT' to 's'
 
 =item HIRAGANA- and KATAKANA VOICED ITERATION MARKs
 
 The VOICED ITERATION MARKs are repleced to a voiced kana
 corresponding to the preceding kana if exists.
 
-  eg.	'́U'   to '͂'
-	'vU'   to 'v'
-	'vS'   to 'vu'
-	'S'   to 'S'
-	'ES'   to 'E'
+  e.g.,
+
+  '́U' to '͂'
+  'vU' to 'v'
+  'vS' to 'vu'
+  'S' to 'S'
+  'ES' to 'E'
 
 =item Cases of no replacement
 
@@ -1354,9 +1456,9 @@ cases when these marks follow any character except kana.
 
 The unreplaced characters are primary greater than any kana.
 
-  eg.	CJK Ideograph followed by PROLONGED SOUND MARK
-	Digit followed by ITERATION MARK
-	'AS' ('A' has no voiced variant)
+  e.g.  CJK Ideograph followed by PROLONGED SOUND MARK
+        Digit followed by ITERATION MARK
+        'AS' ('A' has no voiced variant)
 
 =item Example
 
@@ -1364,17 +1466,19 @@ For example, the Japanese string C<'p['> (C<Perl> in kana)
 has three collation elements: C<KATAKANA PA>,
 C<PROLONGED SOUND MARK replaced by KATAKANA A>, and C<KATAKANA RU>.
 
-	'p[' is converted to 'pA' by replacement.
-		primary equal to '͂'.
-		secondary equal to 'ς', greater than '͂'.
-		tertiary equal to 'ρ[', lesser than 'pA'.
-		quartenary greater than 'ρ['.
+  e.g.,
+
+   'p[' is converted to 'pA' by replacement;
+     primary equal to '͂';
+     condary equal to 'ς', greater than '͂';
+     tertiary equal to 'ρ[', lesser than 'pA';
+     and quartenary greater than 'ρ['.
 
 =back
 
 =head2 Conformance to the Standard
 
-    [cf. the article 6.2, JIS X 4061]
+    [the clause 6.2, JIS X 4061]
 
   (1) charset: Shift_JIS.
 
@@ -1398,8 +1502,8 @@ C<PROLONGED SOUND MARK replaced by KATAKANA A>, and C<KATAKANA RU>.
       is not supported.
 
   (6) Kanji Classes:
-       the minimal kanji class (Five kanji-like chars).
-       the basic kanji class (Levels 1 and 2 kanji, JIS)..
+       i) the minimal kanji class (Five kanji-like chars).
+       ii) the basic kanji class (Levels 1 and 2 kanji of JIS)..
 
 =head1 AUTHOR
 
@@ -1407,7 +1511,9 @@ Tomoyuki SADAHIRO
 
 Copyright (C) 2001-2002. All rights reserved.
 
-bqw10602@nifty.com  http://homepage1.nifty.com/nomenclator/perl/
+E<lt>SADAHIRO@cpan.orgE<gt>
+
+http://homepage1.nifty.com/nomenclator/perl/
 
 This module is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
@@ -1422,7 +1528,12 @@ JIS X 4061 [Collation of Japanese character strings]
 
 =item *
 
-JIS X 0208 [7-bits and 8-bits double byte coded Kanji sets
+JIS X 0201 [7-bit and 8-bit coded character sets
+for information interchange]
+
+=item *
+
+JIS X 0208 [7-bit and 8-bit double byte coded KANJI sets
 for information interchange]
 
 =item *
